# pubsubplus-python-client
#
# Copyright 2021-2022 Solace Corporation. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# 	http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


"""
This module abstracts message receiving behavior; it is a base class for all receivers.
"""
from abc import ABC, abstractmethod
from solace.messaging.receiver.inbound_message import InboundMessage
from solace.messaging.utils.life_cycle_control import LifecycleControl, AsyncLifecycleControl


class MessageReceiver(LifecycleControl, AsyncLifecycleControl):
    """An abstract class that provides the message receiver implementation. """

class MessageHandler(ABC):
    """
    An abstract base class that defines the interface for a message handler for inbound messages.
    """

    @abstractmethod
    def on_message(self, message: InboundMessage):
        """
        Definition for a message processing function.

        Args:
            message(InboundMessage): The inbound message.
        """
